diff --git a/InnerDetector/InDetMonitoring/PixelMonitoring/python/PixelAthMonitoringBase.py b/InnerDetector/InDetMonitoring/PixelMonitoring/python/PixelAthMonitoringBase.py
index b783d9fdac0275083c96912d95a550324b471380..096a4ab21dba897bf5a5148bbf9d82974b29f6ad 100644
--- a/InnerDetector/InDetMonitoring/PixelMonitoring/python/PixelAthMonitoringBase.py
+++ b/InnerDetector/InDetMonitoring/PixelMonitoring/python/PixelAthMonitoringBase.py
@@ -24,7 +24,7 @@ NumPP0sEC       = 24
 btxt     = ";eta index of module"
 sbtxt    = ";shifted eta index of module"
 ditxt    = ";disk number"
-layers   = ["ECA","ECC","B0","B1","B2","IBL"]
+layers   = ["ECA","ECC","BLayer","Layer1","Layer2","IBL"]
 xbinsl   = [    3,    3,  13,  13,  13,   32]
 xminsl   = [ -0.5, -0.5,-6.5,-6.5,-6.5,-16.5]
 ybinsl   = [   48,   48,  22,  38,  52,   14]
@@ -46,10 +46,10 @@ errbminsy= [    0,    0,   0,   0,   0,    0]
 errbbsizy= [    1,    1,   1,   1,   1,    1]
 errtbinsy= [    7,    7,   7,   7,   7,    7]
 
-pp0layers= ["ECA","ECC","B0","B1","B2","IBLA","IBLC"]
+pp0layers= ["ECA","ECC","BLayer","Layer1","Layer2","IBLA","IBLC"]
 pp0xbins = [   24,   24,  22,  38,  52,   14,     14]
 
-fei3layers= ["ECA","ECC","B0","B1","B2"]
+fei3layers= ["ECA","ECC","BLayer","Layer1","Layer2"]
 fei4layers= ["IBL"]
 
 lumitext  = ";lumi block"
diff --git a/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.h b/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.h
index b1c5c317303b1826ddbc94052f02d4682e20ce0f..efc69e85470b72db7c5f88b7f4565e99a294584a 100644
--- a/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.h
+++ b/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.h
@@ -25,7 +25,7 @@ public:
   };
 };
 const std::string pixLayersLabel[PixLayers::COUNT] = {
-  "ECA", "ECC", "B0", "B1", "B2", "IBL"
+  "ECA", "ECC", "BLayer", "Layer1", "Layer2", "IBL"
 };
 const float inv_nmod_per_layer[PixLayers::COUNT] = {
   1. / 144., 1. / 144., 1. / 286., 1. / 494., 1. / 676., 1. / 448.
diff --git a/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.cxx b/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.cxx
index b51c37f6c89bb9fc7dc0c41d8fafadacd5994500..17bbd29d47dc2637f18513788843be594a13f79e 100644
--- a/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.cxx
+++ b/InnerDetector/InDetMonitoring/PixelMonitoring/src/PixelAthMonitoringBase.cxx
@@ -113,7 +113,7 @@ void PixelAthMonitoringBase::fill2DProfLayerAccum(const VecAccumulator2DMap& acc
 }
 
 ///
-/// filling 1DProf per-lumi per-layer histograms ["ECA","ECC","B0","B1","B2","IBL"]
+/// filling 1DProf per-lumi per-layer histograms ["ECA","ECC","BLayer","Layer1","Layer2","IBL"]
 ///
 void PixelAthMonitoringBase::fill1DProfLumiLayers(const std::string& prof1Dname, int lumiblock, float* values,
                                                   int nlayers) const {
@@ -136,7 +136,7 @@ void PixelAthMonitoringBase::fill1DProfLumiLayers(const std::string& prof1Dname,
 //////////////////////////////////////////////
 
 ///
-/// filling 2DProf per-lumi per-layer histograms ["ECA","ECC","B0","B1","B2","IBL"]
+/// filling 2DProf per-lumi per-layer histograms ["ECA","ECC","BLayer","Layer1","Layer2","IBL"]
 ///
 void PixelAthMonitoringBase::fill2DProfLumiLayers(const std::string& prof2Dname, int lumiblock,
                                                   float(*values)[PixLayers::COUNT], const int* nCategories) const {
@@ -159,7 +159,7 @@ void PixelAthMonitoringBase::fill2DProfLumiLayers(const std::string& prof2Dname,
 
 
 ///
 /// filling 1DProfile per-pp0(ROD) histograms for ["ECA","ECC","B0","B1","B2","IBLA","IBLC"]
 ///
 void PixelAthMonitoringBase::fillFromArrays(const std::string& namePP0, AccumulatorArrays& pixarrays,
                                             const std::string& name2DMap) const {
@@ -214,8 +214,8 @@ void PixelAthMonitoringBase::fillFromArrays(const std::string& namePP0, Accumula
       auto valp = Monitored::Scalar<float>(valvarp, pixarrays.B0[a][b]);
       auto valm = Monitored::Scalar<float>(valvarm, pixarrays.B0[a][b] * weightPix);
       if (pixarrays.B0[a][b] > -1) {
-        fill("B0", pospp0x, valp);
-        if (!fillPP0only) fill("B0", posx, posy, valm);
+        fill("BLayer", pospp0x, valp);
+        if (!fillPP0only) fill("BLayer", posx, posy, valm);
       }
     }
     for (unsigned int a = 0; a < PixMon::kNumStavesL1; ++a) {
@@ -224,8 +224,8 @@ void PixelAthMonitoringBase::fillFromArrays(const std::string& namePP0, Accumula
       auto valp = Monitored::Scalar<float>(valvarp, pixarrays.B1[a][b]);
       auto valm = Monitored::Scalar<float>(valvarm, pixarrays.B1[a][b] * weightPix);
       if (pixarrays.B1[a][b] > -1) {
-        fill("B1", pospp0x, valp);
-        if (!fillPP0only) fill("B1", posx, posy, valm);
+        fill("Layer1", pospp0x, valp);
+        if (!fillPP0only) fill("Layer1", posx, posy, valm);
       }
     }
     for (unsigned int a = 0; a < PixMon::kNumStavesL2; ++a) {
@@ -234,8 +234,8 @@ void PixelAthMonitoringBase::fillFromArrays(const std::string& namePP0, Accumula
       auto valp = Monitored::Scalar<float>(valvarp, pixarrays.B2[a][b]);
       auto valm = Monitored::Scalar<float>(valvarm, pixarrays.B2[a][b] * weightPix);
       if (pixarrays.B2[a][b] > -1) {
-        fill("B2", pospp0x, valp);
-        if (!fillPP0only) fill("B2", posx, posy, valm);
+        fill("Layer2", pospp0x, valp);
+        if (!fillPP0only) fill("Layer2", posx, posy, valm);
       }
     }
   }
@@ -159,7 +159,7 @@ void PixelAthMonitoringBase::fill2DProfLumiLayers(const std::string& prof2Dname,
 
 ///
-/// filling 1DProfile per-pp0(ROD) histograms for ["ECA","ECC","B0","B1","B2","IBLA","IBLC"]
+/// filling 1DProfile per-pp0(ROD) histograms for ["ECA","ECC","BLayer","Layer1","Layer2","IBLA","IBLC"]
 ///
 void PixelAthMonitoringBase::fillFromArrays(const std::string& namePP0, AccumulatorArrays& pixarrays,